package xyz.leomurca.csgomatches.ui.screens.details

import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.BoxScope
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.automirrored.filled.ArrowBack
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.collectAsState
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import androidx.hilt.navigation.compose.hiltViewModel
import xyz.leomurca.csgomatches.ui.components.LoadingIndicator
import xyz.leomurca.csgomatches.ui.navigation.DetailsRoute
import xyz.leomurca.csgomatches.ui.theme.White

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun DetailsScreen(
    viewModel: DetailsViewModel = hiltViewModel(),
    details: DetailsRoute,
    onBackClick: () -> Unit
) {
    val uiState = viewModel.uiState.collectAsState()

    LaunchedEffect(Unit) {
        viewModel.loadTeam(details.leftOpponentId.toString(), isLeft = true)
        viewModel.loadTeam(details.rightOpponentId.toString(), isLeft = false)
    }

    Box(
        modifier = Modifier
            .fillMaxSize()
            .background(MaterialTheme.colorScheme.background),
        contentAlignment = Alignment.Center
    ) {
        TopBar(details.leagueAndSerieName, onBackClick)

        val value = uiState.value
        when {
            value.errorMessage != null -> Text(value.errorMessage)
            value.isLoading -> LoadingIndicator()
            value.leftTeam != null && value.rightTeam != null -> Column {
                Text(value.leftTeam.name.toString())
                Text(value.rightTeam.name.toString())
            }
        }
    }
}

@Composable
private fun BoxScope.TopBar(leagueAndSerieName: String, onBackClick: () -> Unit) {
    Row(
        Modifier
            .fillMaxWidth()
            .background(MaterialTheme.colorScheme.background)
            .align(Alignment.TopCenter)
            .padding(top = 52.dp, start = 24.dp, end = 24.dp),
        verticalAlignment = Alignment.CenterVertically,
    ) {
        IconButton(onBackClick, modifier = Modifier) {
            Icon(Icons.AutoMirrored.Default.ArrowBack, contentDescription = "", tint = White)
        }

        Text(
            leagueAndSerieName,
            textAlign = TextAlign.Center,
            style = MaterialTheme.typography.titleMedium,
            color = White,
        )
    }
}
