package xyz.leomurca.csgomatches.ui.screens.details

import androidx.lifecycle.SavedStateHandle
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import dagger.hilt.android.lifecycle.HiltViewModel
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.flow.StateFlow
import kotlinx.coroutines.flow.asStateFlow
import kotlinx.coroutines.flow.update
import kotlinx.coroutines.launch
import xyz.leomurca.csgomatches.domain.model.Resource
import xyz.leomurca.csgomatches.domain.model.Team
import xyz.leomurca.csgomatches.domain.repository.MatchRepository
import javax.inject.Inject

@HiltViewModel
class DetailsViewModel @Inject constructor(
    private val matchRepository: MatchRepository,
) : ViewModel() {

    private val _uiState = MutableStateFlow(TeamUiState())
    val uiState: StateFlow<TeamUiState> = _uiState.asStateFlow()

    fun loadTeam(teamId: String, isLeft: Boolean) {
        viewModelScope.launch {
            _uiState.update { it.copy(isLoading = true, errorMessage = null) }

            when (val result = matchRepository.teamDetails(teamId)) {
                is Resource.Success -> {
                    val team = result.data.firstOrNull()
                    _uiState.update {
                        if (isLeft) it.copy(leftTeam = team, isLoading = false)
                        else it.copy(rightTeam = team, isLoading = false)
                    }
                }

                is Resource.Error -> {
                    _uiState.update {
                        it.copy(errorMessage = result.message, isLoading = false)
                    }
                }
            }
        }
    }

    data class TeamUiState(
        val leftTeam: Team? = null,
        val rightTeam: Team? = null,
        val isLoading: Boolean = true,
        val errorMessage: String? = null
    )
}